@@ -1,6 +1,6 @@
 package IRC::Toolkit;
 {
-  $IRC::Toolkit::VERSION = '0.081001';
+  $IRC::Toolkit::VERSION = '0.082000';
 }
 
 use Carp;
@@ -55,6 +55,7 @@ IRC::Toolkit - Useful IRC objects and utilities
     CTCP
     Masks
     Modes
+    Numerics
   /;
 
 =head1 DESCRIPTION
@@ -80,6 +81,8 @@ L<IRC::Toolkit::Masks>; Hostmask parsing and matching tools
 
 L<IRC::Toolkit::Modes>; Mode-line parsing tools
 
+L<IRC::Toolkit::Numerics>; IRC numerics translation to/from RPL or ERR names
+
 L<IRC::Toolkit::Parser>; Functional interface to L<POE::Filter::IRCv3>
 
 L<IRC::Toolkit::TS6>; Produce TS6 IDs
