@@ -1,6 +1,6 @@
 package IRC::Toolkit::Masks;
 {
-  $IRC::Toolkit::Masks::VERSION = '0.081001';
+  $IRC::Toolkit::Masks::VERSION = '0.082000';
 }
 
 use Carp;
@@ -85,8 +85,11 @@ IRC::Toolkit::Masks - IRC mask-related utilities
 =head1 SYNOPSIS
 
   use IRC::Toolkit::Masks;
-
-  if ( matches_mask($mask, $host, $casemap) ) {
+  
+  my $mask = '*!avenj@*.cobaltirc.org';
+  my $full = 'avenj!avenj@eris.cobaltirc.org';
+  my $casemap = 'rfc1459';
+  if ( matches_mask($mask, $full, $casemap) ) {
     ...
   }
 
@@ -125,7 +128,7 @@ Returns just the nickname in scalar context.
 Mask-matching and normalization code derived from L<IRC::Utils>, 
 copyright Chris Williams, HINRIK et al.
 
-Jon Portnoy L<avenj@cobaltirc.org>
+Jon Portnoy <avenj@cobaltirc.org>
 
 =cut
 
